@@ -209,13 +209,13 @@ f7Tabs <- function(..., .items = NULL, id = NULL, swipeable = FALSE, animated =
         if (style %in% c("segmented", "strong")) {
           shiny::tags$button(
             class = if (active) "button tab-link tab-link-active" else "button tab-link",
-            href = paste0("#", ns(itemId)),
+            `data-tab` = paste0("#", ns(itemId)),
             itemIcon,
             shiny::span(class = "tabbar-label", itemName)
           )
         } else if (style == "toolbar") {
           shiny::a(
-            href = paste0("#", ns(itemId)),
+            `data-tab` = paste0("#", ns(itemId)),
             class = if (active) "tab-link tab-link-active" else "tab-link",
             itemIcon,
             shiny::span(class = "tabbar-label", itemName)
@@ -225,12 +225,12 @@ f7Tabs <- function(..., .items = NULL, id = NULL, swipeable = FALSE, animated =
         if (style %in% c("segmented", "strong")) {
           shiny::tags$button(
             class = if (active) "button tab-link tab-link-active" else "button tab-link",
-            href = paste0("#", ns(itemId)),
+            `data-tab` = paste0("#", ns(itemId)),
             itemName
           )
         } else if (style == "toolbar"){
           shiny::a(
-            href = paste0("#", ns(itemId)),
+            `data-tab` = paste0("#", ns(itemId)),
             class = if (active) "tab-link tab-link-active" else "tab-link",
             itemName
           )
@@ -253,7 +253,8 @@ f7Tabs <- function(..., .items = NULL, id = NULL, swipeable = FALSE, animated =
       class = "block-header",
       shiny::tags$div(
         class = "segmented segmented-strong",
-        tabItems
+        tabItems,
+        shiny::span(class = "segmented-highlight")
       )
     )
   } else if (style == "toolbar") {
@@ -323,7 +324,7 @@ f7Tabs <- function(..., .items = NULL, id = NULL, swipeable = FALSE, animated =
     )
   }
 
-  shiny::tagList(f7InputsDeps(), tabLinksTag, contentTag)
+  shiny::tagList(tabLinksTag, contentTag)
 
 }
 
@@ -406,7 +407,7 @@ f7TabLink <- function(..., icon = NULL, label = NULL) {
 #'  library(shinyMobile)
 #'
 #'  subtabs_ui <- function(id) {
-#'    ns <- shiny::NS(id)
+#'    ns <- NS(id)
 #'
 #'    tagList(
 #'      f7Toggle(inputId = ns("updateSubTab"), label = "Update SubTab", checked = FALSE),
@@ -429,7 +430,7 @@ f7TabLink <- function(..., icon = NULL, label = NULL) {
 #'    return(reactive(input$subtabdemo))
 #'  }
 #'
-#'  shiny::shinyApp(
+#'  shinyApp(
 #'    ui = f7Page(
 #'      title = "Tab Layout",
 #'      f7TabLayout(
@@ -464,7 +465,7 @@ f7TabLink <- function(..., icon = NULL, label = NULL) {
 #'      output$selectedTab <- renderText(input$tabdemo)
 #'      observeEvent(input$updateTab, {
 #'        selected <- ifelse(input$updateTab, "Tab 1", "Tab 2")
-#'        updateF7Tabs(session, id = "tabdemo", selected = selected)
+#'        updateF7Tabs(id = "tabdemo", selected = selected)
 #'      })
 #'      subtab <- callModule(subtabs, "subtabs1")
 #'      output$selectedSubTab <- renderText(subtab())
@@ -474,22 +475,12 @@ f7TabLink <- function(..., icon = NULL, label = NULL) {
 #'  shinyApp(
 #'   ui <- f7Page(
 #'     title = "shinyMobile",
-#'     init = f7Init(
-#'       skin = "auto",
-#'       theme = "light",
-#'       color = 'blue',
-#'       filled = TRUE,
-#'       hideNavOnPageScroll = FALSE,
-#'       hideTabsOnPageScroll = FALSE
-#'     ),
 #'     f7TabLayout(
 #'       navbar = f7Navbar(
 #'         title = "Update Tabs with hidden tab",
 #'         subtitle = "",
 #'         hairline = TRUE,
 #'         shadow = TRUE,
-#'         left_panel = TRUE,
-#'         right_panel = FALSE,
 #'         bigger = FALSE,
 #'         transparent = TRUE
 #'       ),
@@ -526,7 +517,7 @@ f7TabLink <- function(..., icon = NULL, label = NULL) {
 #'   }
 #'  )
 #' }
-updateF7Tabs <- function(session, id, selected = NULL) {
+updateF7Tabs <- function(id, selected = NULL, session = shiny::getDefaultReactiveDomain()) {
 
   # remove the space in the tab name
   selected <- gsub(x = selected, pattern = " ", replacement = "")
@@ -537,9 +528,12 @@ updateF7Tabs <- function(session, id, selected = NULL) {
 
 
 
-#' Insert a \link{f7Tab} in a \link{f7Tabs}
+#' Framework7 tab insertion
 #'
-#' @param inputId  \link{f7Tabs} id.
+#' \link{f7InsertTab} is deprecated. Inserts a \link{f7Tab} in a \link{f7Tabs}.
+#'
+#' @rdname inserttab
+#' @param id  \link{f7Tabs} id.
 #' @param tab \link{f7Tab} to insert.
 #' @param target \link{f7Tab} after of before which the new tab will be inserted.
 #' @param position Insert before or after: \code{c("before", "after")}.
@@ -548,13 +542,11 @@ updateF7Tabs <- function(session, id, selected = NULL) {
 #'
 #' @export
 #'
-#' @importFrom shiny getDefaultReactiveDomain
-#'
 #' @examples
 #' if (interactive()) {
 #'  library(shiny)
 #'  library(shinyMobile)
-#'  shiny::shinyApp(
+#'  shinyApp(
 #'    ui = f7Page(
 #'      title = "Insert a tab Before the target",
 #'      f7TabLayout(
@@ -566,8 +558,8 @@ updateF7Tabs <- function(session, id, selected = NULL) {
 #'          title = "Tabs",
 #'          hairline = FALSE,
 #'          shadow = TRUE,
-#'          left_panel = TRUE,
-#'          right_panel = TRUE
+#'          leftPanel = TRUE,
+#'          rightPanel = TRUE
 #'        ),
 #'        f7Tabs(
 #'          animated = TRUE,
@@ -591,7 +583,7 @@ updateF7Tabs <- function(session, id, selected = NULL) {
 #'    server = function(input, output, session) {
 #'      observeEvent(input$go, {
 #'        f7InsertTab(
-#'          inputId = "tabs",
+#'          id = "tabs",
 #'          position = "before",
 #'          target = "Tab 2",
 #'          tab = f7Tab (tabName = paste0("tab_", input$go), "Test"),
@@ -602,9 +594,17 @@ updateF7Tabs <- function(session, id, selected = NULL) {
 #'  )
 #' }
 #'
-f7InsertTab <- function(inputId, tab, target, position = c("before", "after"),
+f7InsertTab <- function(id, tab, target, position = c("before", "after"),
                         select = FALSE, session = shiny::getDefaultReactiveDomain()) {
 
+  .Deprecated(
+    "insertF7Tab",
+    package = "shinyMobile",
+    "f7InsertTab will be removed in future release. Please use
+    insertF7Tab instead.",
+    old = as.character(sys.call(sys.parent()))[1L]
+  )
+
   # in shinyMobile, f7Tab returns a list of 3 elements:
   # - 1 is the tag\
   # - 2 is the icon name
@@ -612,7 +612,7 @@ f7InsertTab <- function(inputId, tab, target, position = c("before", "after"),
   # Below we check if the tag is really a shiny tag...
   if (!(class(tab[[1]]) %in% c("shiny.tag" , "shiny.tag.list"))) stop("tab must be a shiny tag")
 
-  nsWrapper <- shiny::NS(inputId)
+  nsWrapper <- shiny::NS(id)
   position <- match.arg(position)
 
   # create the corresponding tablink
@@ -620,7 +620,7 @@ f7InsertTab <- function(inputId, tab, target, position = c("before", "after"),
 
   tabLink <- shiny::a(
     class = "tab-link",
-    href = paste0("#", nsWrapper(tab[[1]]$attribs$id)),
+    `data-tab` = paste0("#", nsWrapper(tab[[1]]$attribs$id)),
     tab[[3]]
   )
   tabLink <- as.character(force(tabLink))
@@ -641,25 +641,36 @@ f7InsertTab <- function(inputId, tab, target, position = c("before", "after"),
       target = target,
       position = position,
       select = tolower(select),
-      ns = inputId
+      ns = id
     )
   )
 
   # we need to create a new id not to overlap with the updateF7Tab id
   # prefix by insert_ makes sense
-  inputId <- paste0("insert_", inputId)
-  session$sendCustomMessage(type = inputId, message)
+  id <- paste0("insert_", id)
+  session$sendCustomMessage(type = id, message)
 }
 
 
-
-
-#' Remove a \link{f7Tab} in a \link{f7Tabs}
+#' Framework7 tab insertion
 #'
-#' @param inputId  \link{f7Tabs} id.
+#' \link{insertF7Tab} inserts a \link{f7Tab} in a \link{f7Tabs}.
+#' @rdname inserttab
+#' @export
+insertF7Tab <- f7InsertTab
+
+
+
+#' Framework7 tab deletion
+#'
+#' \link{f7RemoveTab} is deprecated. It removes a \link{f7Tab} in a \link{f7Tabs}.
+#'
+#' @param id  \link{f7Tabs} id.
 #' @param target \link{f7Tab} to remove.
 #' @param session Shiny session object.
 #'
+#' @rdname removetab
+#'
 #' @export
 #'
 #' @examples
@@ -678,8 +689,8 @@ f7InsertTab <- function(inputId, tab, target, position = c("before", "after"),
 #'      title = "Tabs",
 #'      hairline = FALSE,
 #'      shadow = TRUE,
-#'      left_panel = TRUE,
-#'      right_panel = TRUE
+#'      leftPanel = TRUE,
+#'      rightPanel = TRUE
 #'    ),
 #'    f7Tabs(
 #'      id = "tabset1",
@@ -707,21 +718,29 @@ f7InsertTab <- function(inputId, tab, target, position = c("before", "after"),
 #'    observe(print(input$tabset1))
 #'    observeEvent(input$remove1, {
 #'      f7RemoveTab(
-#'        inputId = "tabset1",
+#'        id = "tabset1",
 #'        target = "Tab 1"
 #'      )
 #'    })
 #'  }
 #'  shinyApp(ui, server)
 #' }
-f7RemoveTab <- function(inputId, target, session = shiny::getDefaultReactiveDomain()) {
+f7RemoveTab <- function(id, target, session = shiny::getDefaultReactiveDomain()) {
 
+
+  .Deprecated(
+    "removeF7Tab",
+    package = "shinyMobile",
+    "f7RemoveTab will be removed in future release. Please use
+    removeF7Tab instead.",
+    old = as.character(sys.call(sys.parent()))[1L]
+  )
   # tabsetpanel namespace
-  ns <- inputId
+  ns <- id
 
   # we need to create a new id not to overlap with the updatebs4TabSetPanel id
   # prefix by remove_ makes sense
-  inputId <- paste0("remove_", inputId)
+  id <- paste0("remove_", id)
 
   # remove all whitespace from the target name
   target <- gsub(" ", "", target, fixed = TRUE)
@@ -732,6 +751,14 @@ f7RemoveTab <- function(inputId, target, session = shiny::getDefaultReactiveDoma
       ns = ns
     )
   )
-  session$sendCustomMessage(type = inputId, message = message)
+  session$sendCustomMessage(type = id, message = message)
 
 }
+
+
+#' Framework7 tab deletion
+#'
+#' \link{removeF7Tab} removes a \link{f7Tab} in a \link{f7Tabs}.
+#' @rdname removetab
+#' @export
+removeF7Tab <- f7RemoveTab
