@@ -1,24 +1,27 @@
-#' Create a Framework7 accordion
+#' Framework7 accordion container
 #'
-#' Build a Framework7 accordion
+#' \link{f7Accordion} creates an interactive accordion container.
 #'
 #' @param ... Slot for \link{f7AccordionItem}.
-#' @param inputId Optional id to recover the state of the accordion.
+#' @param id Optional id to recover the state of the accordion.
 #' @param multiCollapse Whether to open multiple items at the same time. FALSE
 #' by default.
 #'
+#' @rdname accordion
+#'
 #' @examples
+#' # Accordion
 #' if(interactive()){
 #'  library(shiny)
 #'  library(shinyMobile)
 #'
-#'  shiny::shinyApp(
+#'  shinyApp(
 #'   ui = f7Page(
 #'     title = "Accordions",
 #'     f7SingleLayout(
 #'      navbar = f7Navbar("Accordions"),
 #'      f7Accordion(
-#'       inputId = "myaccordion1",
+#'       id = "myaccordion1",
 #'       f7AccordionItem(
 #'        title = "Item 1",
 #'        f7Block("Item 1 content"),
@@ -59,7 +62,7 @@
 #' @author David Granjon, \email{dgranjon@@ymail.com}
 #'
 #' @export
-f7Accordion <- function(..., inputId = NULL, multiCollapse = FALSE) {
+f7Accordion <- function(..., id = NULL, multiCollapse = FALSE) {
 
   accordionTag <- if (multiCollapse) {
     shiny::tags$div(
@@ -73,29 +76,25 @@ f7Accordion <- function(..., inputId = NULL, multiCollapse = FALSE) {
     )
   }
 
- accordionTag <- tagAppendAttributes(
+ tagAppendAttributes(
    accordionTag,
-   id = inputId,
+   id = id,
    class = "collapsible"
  )
-
- shiny::tagList(f7InputsDeps(), accordionTag)
-
 }
 
 
 
-#' Create a Framework7 accordion item
+#' Framework7 accordion item
 #'
-#' Build a Framework7 accordion item
+#' \link{f7AccordionItem} is to be inserted in \link{f7Accordion}.
 #'
 #' @param ... Item content such as \link{f7Block} or any f7 element.
 #' @param title Item title.
 #' @param open Whether the item is open at start. FALSE by default.
 #'
-#' @author David Granjon, \email{dgranjon@@ymail.com}
-#'
 #' @export
+#' @rdname accordion
 f7AccordionItem <- function(..., title = NULL, open = FALSE) {
 
   accordionCl <- "accordion-item"
@@ -123,29 +122,31 @@ f7AccordionItem <- function(..., title = NULL, open = FALSE) {
 
 
 
-#' Update a Framework 7 accordion
+#' Update Framework 7 accordion
 #'
-#' @param inputId Accordion instance.
+#' \link{updateF7Accordion} toggles a \link{f7Accordion} on the client.
+#'
+#' @param id Accordion instance.
 #' @param selected Index of item to select.
 #' @param session Shiny session object
 #'
 #' @export
-#'
-#' @importFrom shiny getDefaultReactiveDomain
+#' @rdname accordion
 #'
 #' @examples
+#' # Update accordion
 #' if (interactive()) {
 #'  library(shiny)
 #'  library(shinyMobile)
 #'
-#'  shiny::shinyApp(
+#'  shinyApp(
 #'    ui = f7Page(
 #'      title = "Accordions",
 #'      f7SingleLayout(
 #'        navbar = f7Navbar("Accordions"),
 #'        f7Button(inputId = "go", "Go"),
 #'        f7Accordion(
-#'          inputId = "myaccordion1",
+#'          id = "myaccordion1",
 #'          f7AccordionItem(
 #'            title = "Item 1",
 #'            f7Block("Item 1 content"),
@@ -161,7 +162,7 @@ f7AccordionItem <- function(..., title = NULL, open = FALSE) {
 #'    server = function(input, output, session) {
 #'
 #'      observeEvent(input$go, {
-#'        updateF7Accordion(inputId = "myaccordion1", selected = 2, session = session)
+#'        updateF7Accordion(id = "myaccordion1", selected = 2)
 #'      })
 #'
 #'      observe({
@@ -175,7 +176,7 @@ f7AccordionItem <- function(..., title = NULL, open = FALSE) {
 #'    }
 #'  )
 #' }
-updateF7Accordion <- function(inputId, selected = NULL, session = shiny::getDefaultReactiveDomain()) {
+updateF7Accordion <- function(id, selected = NULL, session = shiny::getDefaultReactiveDomain()) {
   message <-list(selected = selected)
-  session$sendInputMessage(inputId, message)
+  session$sendInputMessage(id, message)
 }
