@@ -1,20 +1,23 @@
-#' Create a Framework7 card
+#' Framework7 card
 #'
-#' Build a Framework7 card
+#' \link{f7Card} creates a simple card container.
+#'
+#' @rdname card
 #'
 #' @param ... Card content.
-#' @param img Card image if any. Displayed in the header.
+#' @param image Card image if any. Displayed in the header.
 #' @param title Card title.
 #' @param footer Footer content, if any. Must be wrapped in a tagList.
 #' @param outline Outline style. FALSE by default.
 #' @param height Card height. NULL by default.
 #'
 #' @examples
+#' # Simple card
 #' if(interactive()){
 #'  library(shiny)
 #'  library(shinyMobile)
 #'
-#'  shiny::shinyApp(
+#'  shinyApp(
 #'   ui = f7Page(
 #'     title = "Cards",
 #'     f7SingleLayout(
@@ -34,7 +37,7 @@
 #'     ),
 #'     f7Card(
 #'      title = "Card header",
-#'      img = "https://lorempixel.com/1000/600/nature/3/",
+#'      image = "https://lorempixel.com/1000/600/nature/3/",
 #'      "This is a simple card with plain text,
 #'      but cards can also contain their own header,
 #'      footer, list view, image, or any other element.",
@@ -52,11 +55,11 @@
 #' @author David Granjon, \email{dgranjon@@ymail.com}
 #'
 #' @export
-f7Card <- function(..., img = NULL, title = NULL, footer = NULL, outline = FALSE,
+f7Card <- function(..., image = NULL, title = NULL, footer = NULL, outline = FALSE,
                    height = NULL) {
 
   cardCl <- "card"
-  if (!is.null(img)) cardCl <- paste0(cardCl, " demo-card-header-pic")
+  if (!is.null(image)) cardCl <- paste0(cardCl, " demo-card-header-pic")
   if (outline) cardCl <- paste0(cardCl, " card-outline")
 
   cardStyle <- NULL
@@ -73,9 +76,9 @@ f7Card <- function(..., img = NULL, title = NULL, footer = NULL, outline = FALSE
 
   # header
   headerTag <- if (!is.null(title)) {
-    if (!is.null(img)) {
+    if (!is.null(image)) {
       shiny::tags$div(
-        style = paste0("background-image:url(", img, ")"),
+        style = paste0("background-image:url(", image, ")"),
         class = "card-header align-items-flex-end",
         title
       )
@@ -90,7 +93,7 @@ f7Card <- function(..., img = NULL, title = NULL, footer = NULL, outline = FALSE
   }
 
   # main tag
-  mainTag <- if (!is.null(img)) {
+  mainTag <- if (!is.null(image)) {
     shiny::tags$div(
       class = "card demo-card-header-pic",
       headerTag,
@@ -110,32 +113,35 @@ f7Card <- function(..., img = NULL, title = NULL, footer = NULL, outline = FALSE
 }
 
 
-#' Create a Framework7 social card
+#' Framework7 social card
 #'
-#' Build a Framework7 social card
+#' \link{f7SocialCard} is a special card for social content.
+#'
+#' @rdname card
 #'
 #' @param ... Card content.
-#' @param author_img Author img.
+#' @param image Author img.
 #' @param author Author.
 #' @param date Date.
 #' @param footer Footer content, if any. Must be wrapped in a tagList.
 #'
 #' @examples
+#' # Social card
 #' if(interactive()){
 #'  library(shiny)
 #'  library(shinyMobile)
 #'
-#'  shiny::shinyApp(
+#'  shinyApp(
 #'   ui = f7Page(
 #'     title = "Social Card",
 #'     f7SingleLayout(
 #'      navbar = f7Navbar(title = "f7SocialCard"),
 #'      f7SocialCard(
-#'      author_img = "http://lorempixel.com/68/68/people/1/",
+#'      image = "https://lorempixel.com/68/68/people/1/",
 #'      author = "John Doe",
 #'      date = "Monday at 3:47 PM",
 #'      "What a nice photo i took yesterday!",
-#'      img(src = "http://lorempixel.com/1000/700/nature/8/", width = "100%"),
+#'      img(src = "https://lorempixel.com/1000/700/nature/8/", width = "100%"),
 #'      footer = tagList(
 #'       f7Badge("1", color = "yellow"),
 #'       f7Badge("2", color = "green"),
@@ -148,17 +154,15 @@ f7Card <- function(..., img = NULL, title = NULL, footer = NULL, outline = FALSE
 #'  )
 #' }
 #'
-#' @author David Granjon, \email{dgranjon@@ymail.com}
-#'
 #' @export
-f7SocialCard <- function(..., author_img = NULL, author = NULL, date = NULL,
+f7SocialCard <- function(..., image = NULL, author = NULL, date = NULL,
                          footer = NULL) {
 
   headerTag <- shiny::tags$div(
     class = "card-header",
     shiny::tags$div(
       class = "demo-facebook-avatar",
-      shiny::img(src = author_img, width = "34", height = "34")
+      shiny::img(src = image, width = "34", height = "34")
     ),
     shiny::tags$div(class = "demo-facebook-name", author),
     shiny::tags$div(class = "demo-facebook-date", date)
@@ -182,28 +186,32 @@ f7SocialCard <- function(..., author_img = NULL, author = NULL, date = NULL,
 
 
 
-#' Create a Framework7 expandable card
+#' Framework7 expandable card
 #'
-#' Build a Framework7 expandable card
+#' \link{f7ExpandableCard} is a card that can expand. Ideal for a
+#' gallery.
+#'
+#' @rdname card
 #'
 #' @param id Unique card id. Useful to handle multiple cards in the DOM.
 #' @param ... Card content.
 #' @param title Card title.
 #' @param subtitle Card subtitle.
-#' @param color Card background color. See \url{http://framework7.io/docs/cards.html}.
+#' @param color Card background color. See \url{https://framework7.io/docs/cards.html}.
 #' Not compatible with the img argument.
-#' @param img Card background image url. Tje JPG format is prefered. Not compatible
+#' @param image Card background image url. Tje JPG format is prefered. Not compatible
 #' with the color argument.
 #' @param fullBackground Whether the image should cover the entire card.
 #'
-#' @note img and color are not compatible. Choose one of them.
+#' @note For \link{f7ExpandableCard}, image and color are not compatible. Choose one of them.
 #'
 #' @examples
+#' # Expandable card
 #' if(interactive()){
 #'  library(shiny)
 #'  library(shinyMobile)
 #'
-#'  shiny::shinyApp(
+#'  shinyApp(
 #'   ui = f7Page(
 #'     title = "Expandable Cards",
 #'     f7SingleLayout(
@@ -234,7 +242,7 @@ f7SocialCard <- function(..., author_img = NULL, author = NULL, date = NULL,
 #'       f7ExpandableCard(
 #'        id = "card3",
 #'        title = "Expandable Card 3",
-#'        img = "https://i.pinimg.com/originals/73/38/6e/73386e0513d4c02a4fbb814cadfba655.jpg",
+#'        image = "https://i.pinimg.com/originals/73/38/6e/73386e0513d4c02a4fbb814cadfba655.jpg",
 #'        "Framework7 - is a free and open source HTML mobile framework
 #'         to develop hybrid mobile apps or web apps with iOS or Android
 #'         native look and feel. It is also an indispensable prototyping apps tool
@@ -244,7 +252,7 @@ f7SocialCard <- function(..., author_img = NULL, author = NULL, date = NULL,
 #'        id = "card4",
 #'        title = "Expandable Card 4",
 #'        fullBackground = TRUE,
-#'        img = "https://i.ytimg.com/vi/8q_kmxwK5Rg/maxresdefault.jpg",
+#'        image = "https://i.ytimg.com/vi/8q_kmxwK5Rg/maxresdefault.jpg",
 #'        "Framework7 - is a free and open source HTML mobile framework
 #'               to develop hybrid mobile apps or web apps with iOS or Android
 #'               native look and feel. It is also an indispensable prototyping apps tool
@@ -256,12 +264,10 @@ f7SocialCard <- function(..., author_img = NULL, author = NULL, date = NULL,
 #'  )
 #' }
 #'
-#' @author David Granjon, \email{dgranjon@@ymail.com}
-#'
 #' @export
 f7ExpandableCard <- function(..., id = NULL, title = NULL,
                              subtitle = NULL, color = NULL,
-                             img = NULL, fullBackground = FALSE) {
+                             image = NULL, fullBackground = FALSE) {
 
   cardColorCl <- if (!is.null(color)) paste0("bg-color-", color)
 
@@ -274,7 +280,7 @@ f7ExpandableCard <- function(..., id = NULL, title = NULL,
         paste0("card-header display-block")
       },
       title,
-      style = if (!is.null(img) & !fullBackground) "height: 60px",
+      style = if (!is.null(image) & !fullBackground) "height: 60px",
       if (!is.null(subtitle)) {
         shiny::tagList(
           shiny::br(),
@@ -294,11 +300,11 @@ f7ExpandableCard <- function(..., id = NULL, title = NULL,
 
 
   # background image if any
-  backgroundImg <- if (!is.null(img)) {
+  backgroundImg <- if (!is.null(image)) {
     if (fullBackground) {
       shiny::tags$div(
         style = paste0(
-          "background: url('", img, "') no-repeat center top;
+          "background: url('", image, "') no-repeat center top;
                 background-size: cover;
                 height: 400px"
         ),
@@ -308,7 +314,7 @@ f7ExpandableCard <- function(..., id = NULL, title = NULL,
     } else {
       shiny::tags$div(
         style = paste0(
-          "background: url('", img, "') no-repeat center bottom;
+          "background: url('", image, "') no-repeat center bottom;
                 background-size: cover;
                 height: 240px"
         )
@@ -321,55 +327,54 @@ f7ExpandableCard <- function(..., id = NULL, title = NULL,
   cardContent <- shiny::tags$div(class = "card-content-padding", shiny::p(...))
 
   # main wrapper
-  shiny::tagList(
-    f7InputsDeps(),
+  shiny::tags$div(
+    class = "card card-expandable",
+    `data-card` = paste0("#", id),
+    id = id,
     shiny::tags$div(
-      class = "card card-expandable",
-      `data-card` = paste0("#", id),
-      id = id,
-      shiny::tags$div(
-        class = "card-content",
-        if (!is.null(img)) {
-          if (!fullBackground) {
-            shiny::tagList(
-              backgroundImg,
-              closeCard,
-              cardHeader
-            )
-          } else {
-            backgroundImg
-          }
-        } else {
-          shiny::tags$div(
-            class = cardColorCl,
-            style = "height: 300px;",
-            cardHeader,
-            closeCard
+      class = "card-content",
+      if (!is.null(image)) {
+        if (!fullBackground) {
+          shiny::tagList(
+            backgroundImg,
+            closeCard,
+            cardHeader
           )
-        },
-        cardContent
-      )
+        } else {
+          backgroundImg
+        }
+      } else {
+        shiny::tags$div(
+          class = cardColorCl,
+          style = "height: 300px;",
+          cardHeader,
+          closeCard
+        )
+      },
+      cardContent
     )
   )
 }
 
 
 
-#' Update a framework 7 expandable card
+#' Update Framework7 expandable card
+#'
+#' \link{updateF7Card} maximizes a \link{f7ExpandableCard} on the client.
 #'
 #' @param id Card id.
 #' @param session Shiny session object.
 #'
+#' @rdname card
 #' @export
 #'
-#' @importFrom shiny getDefaultReactiveDomain
-#'
 #' @examples
+#' # Update expandable card
 #' if (interactive()) {
 #'  library(shiny)
 #'  library(shinyMobile)
 #'
-#'  shiny::shinyApp(
+#'  shinyApp(
 #'    ui = f7Page(
 #'      title = "Expandable Cards",
 #'      f7SingleLayout(
@@ -381,7 +386,7 @@ f7ExpandableCard <- function(..., id = NULL, title = NULL,
 #'        f7ExpandableCard(
 #'          id = "card1",
 #'          title = "Expandable Card 1",
-#'          img = "https://i.pinimg.com/originals/73/38/6e/73386e0513d4c02a4fbb814cadfba655.jpg",
+#'          image = "http://i.pinimg.com/originals/73/38/6e/73386e0513d4c02a4fbb814cadfba655.jpg",
 #'          "Framework7 - is a free and open source HTML mobile framework
 #'          to develop hybrid mobile apps or web apps with iOS or Android
 #'          native look and feel. It is also an indispensable prototyping apps tool
@@ -396,7 +401,7 @@ f7ExpandableCard <- function(..., id = NULL, title = NULL,
 #'          id = "card2",
 #'          title = "Expandable Card 2",
 #'          fullBackground = TRUE,
-#'          img = "https://i.ytimg.com/vi/8q_kmxwK5Rg/maxresdefault.jpg",
+#'          image = "http://i.ytimg.com/vi/8q_kmxwK5Rg/maxresdefault.jpg",
 #'          "Framework7 - is a free and open source HTML mobile framework
 #'                to develop hybrid mobile apps or web apps with iOS or Android
 #'                native look and feel. It is also an indispensable prototyping apps tool
@@ -407,7 +412,7 @@ f7ExpandableCard <- function(..., id = NULL, title = NULL,
 #'    server = function(input, output, session) {
 #'
 #'      observeEvent(input$go, {
-#'        updateF7Card(id = "card2", session = session)
+#'        updateF7Card(id = "card2")
 #'      })
 #'
 #'      observe({
