@@ -1,6 +1,8 @@
-#' Create a Framework7 gauge
+#' Framework7 gauge
 #'
-#' Build a Framework7 gauge
+#' \link{f7Gauge} creates a gauge instance.
+#'
+#' @rdname gauge
 #'
 #' @param id Gauge ID.
 #' @param type Gauge type. Can be "circle" or "semicircle". Default is "circle."
@@ -19,11 +21,12 @@
 #' @param labelFontWeight Label text font weight.
 #'
 #' @examples
+#' # Gauge
 #' if(interactive()){
 #'  library(shiny)
 #'  library(shinyMobile)
 #'
-#'  shiny::shinyApp(
+#'  shinyApp(
 #'   ui = f7Page(
 #'     title = "Gauges",
 #'     f7SingleLayout(
@@ -46,7 +49,7 @@
 #'  )
 #' }
 #'
-#' @author David Granjon and Isabelle Rudolf, \email{dgranjon@@ymail.com}
+#' @author David Granjon \email{dgranjon@@ymail.com}
 #'
 #' @export
 f7Gauge <- function(id, type = "circle", value, size = 200,
@@ -79,14 +82,17 @@ f7Gauge <- function(id, type = "circle", value, size = 200,
   )
 
   # do.call preserve the data format
-  shiny::tagList(f7InputsDeps(), do.call(shiny::tags$div, gaugeProps))
+  do.call(shiny::tags$div, gaugeProps)
 }
 
 
 
-#' update a framework7 gauge from the server side
+#' Update Framework7 gauge
+#'
+#' \link{updateF7Gauge} updates a framework7 gauge from the server side.
+#'
+#' @rdname gauge
 #'
-#' @param session Shiny session object.
 #' @param id Gauge id.
 #' @param value New value. Numeric between 0 and 100.
 #' @param size Generated SVG image size (in px). Default is 200.
@@ -101,6 +107,7 @@ f7Gauge <- function(id, type = "circle", value, size = 200,
 #' @param labelTextColor Label text color.
 #' @param labelFontSize Label text font size.
 #' @param labelFontWeight Label text font weight.
+#' @param session Shiny session object.
 #'
 #' @export
 #'
@@ -110,7 +117,7 @@ f7Gauge <- function(id, type = "circle", value, size = 200,
 #'  library(shinyMobile)
 #'
 #'
-#'  shiny::shinyApp(
+#'  shinyApp(
 #'     ui = f7Page(
 #'        title = "Gauges",
 #'        f7SingleLayout(
@@ -130,17 +137,18 @@ f7Gauge <- function(id, type = "circle", value, size = 200,
 #'     ),
 #'     server = function(input, output, session) {
 #'        observeEvent(input$go, {
-#'           updateF7Gauge(session, id = "mygauge", value = 75, labelText = "New label!")
+#'           updateF7Gauge(id = "mygauge", value = 75, labelText = "New label!")
 #'        })
 #'     }
 #'  )
 #' }
-updateF7Gauge <- function(session, id, value = NULL, labelText = NULL, size = NULL,
+updateF7Gauge <- function(id, value = NULL, labelText = NULL, size = NULL,
                           bgColor = NULL, borderBgColor = NULL,
                           borderColor = NULL, borderWidth = NULL,
                           valueTextColor = NULL, valueFontSize = NULL,
                           valueFontWeight = NULL, labelTextColor = NULL,
-                          labelFontSize = NULL, labelFontWeight = NULL) {
+                          labelFontSize = NULL, labelFontWeight = NULL,
+                          session = shiny::getDefaultReactiveDomain()) {
 
   message <- dropNulls(
     list(
