@@ -1,24 +1,23 @@
-#' Create a Framework7 link
+#' Framework7 link
 #'
-#' Build a Framework7 link
+#' Link to point toward external content.
 #'
 #' @param label Link text.
 #' @param icon Link icon, if any.
-#' @param src Link source, url.
-#' @param external Whether switch to an external link. FALSE by default.
+#' @param href Link source, url.
 #'
 #' @examples
 #' if(interactive()){
 #'  library(shiny)
 #'  library(shinyMobile)
 #'
-#'  shiny::shinyApp(
+#'  shinyApp(
 #'    ui = f7Page(
 #'     title = "Links",
 #'     f7SingleLayout(
 #'      navbar = f7Navbar(title = "f7Link"),
-#'      f7Link(label = "Google", src = "https://www.google.com"),
-#'      f7Link(label = "Google", src = "https://www.google.com", external = TRUE)
+#'      f7Link(label = "Google", href = "https://www.google.com"),
+#'      f7Link(label = "Twitter", href = "https://www.twitter.com")
 #'     )
 #'    ),
 #'    server = function(input, output) {}
@@ -28,13 +27,12 @@
 #' @author David Granjon, \email{dgranjon@@ymail.com}
 #'
 #' @export
-f7Link <- function(label = NULL, icon = NULL, src = NULL, external = FALSE) {
+f7Link <- function(label, href, icon = NULL) {
 
-  linkCl <- "link"
-  if (external) linkCl <- paste0(linkCl, " external")
+  linkCl <- "link external"
 
  shiny::a(
-   href = src,
+   href = href,
    target = "_blank",
    class = linkCl,
    if (!is.null(icon)) {
