@@ -1,6 +1,7 @@
-#' Create a Framework7 Navbar
+#' Framework7 Navbar
 #'
-#' Build a Framework7 Navbar
+#' Build a navbar layout element to insert in \link{f7SingleLayout},
+#' \link{f7TabLayout} or \link{f7SplitLayout}.
 #'
 #' @param ... Slot for \link{f7SearchbarTrigger}. Not compatible with \link{f7Panel}.
 #' @param subNavbar \link{f7SubNavbar} slot, if any.
@@ -12,17 +13,19 @@
 #' compatible with subtitle.
 #' @param transparent Whether the navbar should be transparent. FALSE by default.
 #' Only works if bigger is TRUE.
-#' @param left_panel Whether to enable the left panel. FALSE by default.
-#' @param right_panel Whether to enable the right panel. FALSE by default.
+#' @param leftPanel Whether to enable the left panel. FALSE by default.
+#' @param rightPanel Whether to enable the right panel. FALSE by default.
 #'
 #' @note Currently, bigger parameters does mess with the CSS.
 #'
 #' @author David Granjon, \email{dgranjon@@ymail.com}
 #'
+#' @rdname navbar
+#'
 #' @export
 f7Navbar <- function(..., subNavbar = NULL, title = NULL, subtitle = NULL, hairline = TRUE,
-                     shadow = TRUE, bigger = FALSE, transparent = FALSE, left_panel = FALSE,
-                     right_panel = FALSE) {
+                     shadow = TRUE, bigger = FALSE, transparent = FALSE, leftPanel = FALSE,
+                     rightPanel = FALSE) {
 
    navbarClass <- "navbar"
    # bigger and transparent work together
@@ -36,7 +39,7 @@ f7Navbar <- function(..., subNavbar = NULL, title = NULL, subtitle = NULL, hairl
    if (!hairline) navbarClass <- paste0(navbarClass, " no-hairline")
    if (!shadow) navbarClass <- paste0(navbarClass, " no-shadow")
 
-   leftNav <- if (left_panel) {
+   leftNav <- if (leftPanel) {
       shiny::tags$div(
          class = "left",
          shiny::tags$a(
@@ -49,7 +52,7 @@ f7Navbar <- function(..., subNavbar = NULL, title = NULL, subtitle = NULL, hairl
       )
    }
 
-   rightNav <- if (right_panel) {
+   rightNav <- if (rightPanel) {
       shiny::tags$div(
          class = "right",
          shiny::tags$a(
@@ -103,7 +106,10 @@ f7Navbar <- function(..., subNavbar = NULL, title = NULL, subtitle = NULL, hairl
 }
 
 
-#' Create a Framework7 sub navbar
+#' Framework7 sub navbar
+#'
+#' \link{f7SubNavbar} creates a nested navbar component for
+#' \link{f7Navbar}.
 #'
 #' @param ... Any elements.
 #'
@@ -114,7 +120,7 @@ f7Navbar <- function(..., subNavbar = NULL, title = NULL, subtitle = NULL, hairl
 #'  library(shiny)
 #'  library(shinyMobile)
 #'
-#'  shiny::shinyApp(
+#'  shinyApp(
 #'   ui = f7Page(
 #'      title = "Sub Navbar",
 #'      f7TabLayout(
@@ -126,8 +132,8 @@ f7Navbar <- function(..., subNavbar = NULL, title = NULL, subtitle = NULL, hairl
 #'            title = "SubNavbar",
 #'            hairline = FALSE,
 #'            shadow = TRUE,
-#'            left_panel = TRUE,
-#'            right_panel = TRUE,
+#'            leftPanel = TRUE,
+#'            rightPanel = TRUE,
 #'            subNavbar = f7SubNavbar(
 #'               f7Button(label = "My button", outline = TRUE),
 #'               f7Button(label = "My button", outline = TRUE),
@@ -178,25 +184,27 @@ f7SubNavbar <- function(...) {
 
 
 
-#' Hide a framework7 navbar
+#' Hide a Framework7 navbar
+#'
+#' \link{f7HideNavbar} hides a \link{f7Navbar} component from the
+#' server. Deprecated, use \link{updateF7Navbar} instead.
 #'
-#' @param session Shiny session object.
 #' @param animate Whether it should be hidden with animation or not. By default is TRUE.
 #' @param hideStatusbar  When FALSE (default) it hides navbar partially keeping space
 #' required to cover statusbar area. Otherwise, navbar will be fully hidden.
+#' @param session Shiny session object.
 #'
 #' @export
-#'
-#' @importFrom shiny getDefaultReactiveDomain
+#' @rdname navbar
 #'
 #' @examples
 #' if (interactive()) {
 #'  library(shiny)
 #'  library(shinyMobile)
 #'
-#'  shiny::shinyApp(
+#'  shinyApp(
 #'     ui = f7Page(
-#'        title = "Accordions",
+#'        title = "Hide navbar",
 #'        f7SingleLayout(
 #'           navbar = f7Navbar("Hide/Show navbar"),
 #'           f7Segment(
@@ -217,8 +225,17 @@ f7SubNavbar <- function(...) {
 #'     }
 #'  )
 #' }
-f7HideNavbar <- function(session = shiny::getDefaultReactiveDomain(), animate = TRUE,
-                         hideStatusbar = FALSE) {
+f7HideNavbar <- function(animate = TRUE, hideStatusbar = FALSE,
+                         session = shiny::getDefaultReactiveDomain()) {
+
+   .Deprecated(
+      "updateF7Navbar",
+      package = "shinyMobile",
+      "f7HideNavbar will be removed in future release. Please use
+    updateF7Navbar instead.",
+      old = as.character(sys.call(sys.parent()))[1L]
+   )
+
    message <- dropNulls(
       list(
          animate = tolower(animate),
@@ -230,43 +247,70 @@ f7HideNavbar <- function(session = shiny::getDefaultReactiveDomain(), animate =
 
 
 
-#' Show a framework7 navbar
+#' Show a Framework7 navbar
+#'
+#' \link{f7ShowNavbar} shows a \link{f7Navbar} component from the
+#' server. Deprecated, use \link{updateF7Navbar} instead.
 #'
-#' @param session Shiny session object.
 #' @param animate Whether it should be hidden with animation or not. By default is TRUE.
+#' @param session Shiny session object.
+#'
+#' @export
+f7ShowNavbar <- function(animate = TRUE, session = shiny::getDefaultReactiveDomain()) {
+   .Deprecated(
+      "updateF7Navbar",
+      package = "shinyMobile",
+      "f7ShowNavbar will be removed in future release. Please use
+    updateF7Navbar instead.",
+      old = as.character(sys.call(sys.parent()))[1L]
+   )
+   session$sendCustomMessage(type = "show_navbar", message = tolower(animate))
+}
+
+
+
+
+#' Toggle a Framework7 navbar
+#'
+#' \link{updateF7Navbar} toggles a \link{f7Navbar} component from the
+#' server.
+#'
+#' @param animate Whether it should be hidden with animation or not. By default is TRUE.
+#' @param hideStatusbar  When FALSE (default) it hides navbar partially keeping space
+#' required to cover statusbar area. Otherwise, navbar will be fully hidden.
+#' @param session Shiny session object.
+#' @rdname navbar
 #'
 #' @export
 #'
-#' @importFrom shiny getDefaultReactiveDomain
-#'
 #' @examples
+#' # Toggle f7Navbar
 #' if (interactive()) {
 #'  library(shiny)
 #'  library(shinyMobile)
 #'
-#'  shiny::shinyApp(
+#'  shinyApp(
 #'     ui = f7Page(
-#'        title = "Accordions",
+#'        title = "Show navbar",
 #'        f7SingleLayout(
 #'           navbar = f7Navbar("Hide/Show navbar"),
-#'           f7Segment(
-#'              f7Button(inputId = "hide", "Hide navbar", color = "red"),
-#'              f7Button(inputId = "show", "Show navbar", color = "green"),
-#'           )
+#'           f7Button(inputId = "toggle", "Toggle navbar", color = "red")
 #'        )
 #'     ),
 #'     server = function(input, output, session) {
 #'
-#'        observeEvent(input$hide, {
-#'           f7HideNavbar()
-#'        })
-#'
-#'        observeEvent(input$show, {
-#'           f7ShowNavbar()
+#'        observeEvent(input$toggle, {
+#'           updateF7Navbar()
 #'        })
 #'     }
 #'  )
 #' }
-f7ShowNavbar <- function(session = shiny::getDefaultReactiveDomain(), animate = TRUE) {
-   session$sendCustomMessage(type = "show_navbar", message = tolower(animate))
+updateF7Navbar <- function(animate = TRUE, hideStatusbar = FALSE, session = shiny::getDefaultReactiveDomain()) {
+   message <- jsonlite::toJSON(
+      list(
+         animate = animate,
+         hideStatusbar = hideStatusbar
+      )
+   )
+   session$sendCustomMessage(type = "toggle_navbar", message = message)
 }
