@@ -1,4 +1,6 @@
-#' Create a Framework 7 searchbar
+#' Framework 7 searchbar
+#'
+#' Searchbar to filter elements in a page.
 #'
 #' @param id Necessary when using \link{f7SearchbarTrigger}. NULL otherwise.
 #' @param placeholder Searchbar placeholder.
@@ -16,9 +18,9 @@
 #'
 #' cars <- rownames(mtcars)
 #'
-#' shiny::shinyApp(
+#' shinyApp(
 #'   ui = f7Page(
-#'     title = "My app",
+#'     title = "Simple searchbar",
 #'     f7SingleLayout(
 #'       navbar = f7Navbar(
 #'         title = "f7Searchbar",
@@ -52,7 +54,7 @@
 #'
 #'  shiny::shinyApp(
 #'    ui = f7Page(
-#'      title = "My app",
+#'      title = "Expandable searchbar",
 #'      f7SingleLayout(
 #'        navbar = f7Navbar(
 #'          title = "f7Searchbar with trigger",
@@ -83,9 +85,9 @@
 #'  )
 #'
 #'  # Searchbar in \link{f7Appbar}
-#'  shiny::shinyApp(
+#'  shinyApp(
 #'   ui = f7Page(
-#'     title = "My app",
+#'     title = "Searchbar in appbar",
 #'     f7Appbar(
 #'       f7Searchbar(id = "search1", inline = TRUE)
 #'     ),
@@ -105,12 +107,12 @@
 #'   server = function(input, output) {}
 #'  )
 #' }
-f7Searchbar <- function(id = NULL, placeholder = "Search", expandable = FALSE, inline = FALSE) {
+f7Searchbar <- function(id, placeholder = "Search", expandable = FALSE, inline = FALSE) {
 
   searchBarCl <- "searchbar"
   if (expandable) searchBarCl <- paste0(searchBarCl, " searchbar-expandable")
 
-  searchBarTag <- if (inline) {
+  if (inline) {
     shiny::tags$div(
       class = "searchbar searchbar-inline",
       id = id,
@@ -138,40 +140,15 @@ f7Searchbar <- function(id = NULL, placeholder = "Search", expandable = FALSE, i
     )
   }
 
-
-  searchBarJS <- shiny::singleton(
-    shiny::tags$script(
-      shiny::HTML(
-        paste0(
-          "$(function() {
-            // create searchbar
-            app.searchbar.create({
-              el: '#", id, "',
-              searchContainer: '.list',
-              searchIn: '.item-title',
-              backdrop: false,
-              on: {
-                search(sb, query, previousQuery) {
-                  console.log(query, previousQuery);
-                }
-              }
-            });
-          });
-          "
-        )
-      )
-    )
-  )
-
-  shiny::tagList(searchBarJS, searchBarTag)
-
 }
 
 
 
-#' Create a Framework 7 searchbar trigger
+#' Framework 7 searchbar trigger
 #'
-#' @param targetId Id of the \link{f7Searchbar}
+#' Element that triggers the searchbar.
+#'
+#' @param targetId Id of the \link{f7Searchbar}.
 #' @export
 #'
 #' @examples
