@@ -17,17 +17,7 @@ sapply(
 # shiny app
 shinyApp(
   ui = f7Page(
-    title = "shinyMobile",
-    init = f7Init(
-      skin = "ios",
-      theme = "dark",
-      filled = TRUE,
-      hideNavOnPageScroll = FALSE,
-      hideTabsOnPageScroll = FALSE,
-      serviceWorker = "service-worker.js",
-      iosTranslucentBars = FALSE,
-      pullToRefresh = FALSE
-    ),
+    allowPWA = TRUE,
     f7TabLayout(
       appbar = f7Appbar(
         f7Flex(f7Back(targetId = "tabset"), f7Next(targetId = "tabset")),
@@ -36,7 +26,7 @@ shinyApp(
       messagebar = f7MessageBar(inputId = "mymessagebar", placeholder = "Message"),
       panels = tagList(
         f7Panel(
-          inputId = "panelLeft",
+          id = "panelLeft",
           title = "Left Panel",
           side = "left",
           theme = "light",
@@ -56,8 +46,8 @@ shinyApp(
         subtitle = "for Shiny",
         hairline = TRUE,
         shadow = TRUE,
-        left_panel = TRUE,
-        right_panel = TRUE,
+        leftPanel = TRUE,
+        rightPanel = TRUE,
         bigger = TRUE,
         transparent = FALSE
       ),
@@ -71,7 +61,7 @@ shinyApp(
       ),
       # recover the color picker input and update the text background
       # color accordingly.
-      shiny::tags$script(
+      tags$script(
         "$(function() {
           Shiny.addCustomMessageHandler('text-color', function(message) {
             $('#colorPickerVal').css('background-color', message);
@@ -102,7 +92,8 @@ shinyApp(
         tabInfo,
         tabOthers
       )
-    )
+    ),
+    title = "shinyMobile"
   ),
   server = function(input, output, session) {
 
@@ -171,6 +162,9 @@ shinyApp(
       trigger = trigger
     )
 
+    output$sin <- renderPlot(plot(sin, -pi, 2*pi))
+    output$cos <- renderPlot(plot(cos, -pi, 2*pi))
+
     output$text <- renderPrint(input$text)
     output$password <- renderPrint(input$password)
     output$textarea <- renderPrint(input$textarea)
@@ -196,7 +190,7 @@ shinyApp(
     output$colorPickerVal <- renderText(input$mycolorpicker)
 
     # send the color picker input to JS
-    observe({
+    observeEvent(input$mycolorpicker, {
       session$sendCustomMessage(type = "text-color", message = input$mycolorpicker)
     })
 
@@ -212,7 +206,6 @@ shinyApp(
       if (input$tabset == "Popups") {
         popupStatus <- if (input$popup1) "opened" else "closed"
         f7Toast(
-          session,
           position = "top",
           text = paste("Popup is", popupStatus)
         )
@@ -225,7 +218,7 @@ shinyApp(
     })
 
     observeEvent(input$toggleSheet, {
-      updateF7Sheet(inputId = "sheet1", session = session)
+      updateF7Sheet(id = "sheet1")
     })
 
     # notifications
@@ -239,8 +232,7 @@ shinyApp(
           icon = icon,
           title = paste("Notification", i),
           subtitle = "A subtitle",
-          titleRightText = i,
-          session = session
+          titleRightText = i
         )
       })
     })
@@ -253,31 +245,28 @@ shinyApp(
         if (i == 1) {
           f7Dialog(
             title = "Dialog title",
-            text = "This is an alert dialog",
-            session = session
+            text = "This is an alert dialog"
           )
         } else if (i == 2) {
           f7Dialog(
-            inputId = "confirmDialog",
+            id = "confirmDialog",
             title = "Dialog title",
             type = "confirm",
-            text = "This is an confirm dialog",
-            session = session
+            text = "This is an confirm dialog"
           )
         } else if (i == 3) {
           f7Dialog(
-            inputId = "promptDialog",
+            id = "promptDialog",
             title = "Dialog title",
             type = "prompt",
-            text = "This is a prompt dialog",
-            session = session
+            text = "This is a prompt dialog"
           )
         }
       })
     })
 
     observeEvent(input$confirmDialog, {
-      f7Toast(session, text = paste("Alert input is:", input$confirmDialog))
+      f7Toast(text = paste("Alert input is:", input$confirmDialog))
     })
 
     output$promptres <- renderUI({
@@ -291,15 +280,13 @@ shinyApp(
     observe({
       f7Popover(
         targetId = "popoverTrigger",
-        content = "This is a f7Button",
-        session
+        content = "This is a f7Button"
       )
     })
 
     # toasts
     observeEvent(input$toast, {
       f7Toast(
-        session,
         position = "bottom",
         text = "I am a toast. Eat me!"
       )
@@ -331,16 +318,14 @@ shinyApp(
           text = "You clicked on the first button",
           icon = f7Icon("bolt_fill"),
           title = "Notification",
-          titleRightText = "now",
-          session = session
+          titleRightText = "now"
         )
       } else if (input$action1_button == 2) {
         f7Dialog(
-          inputId = "actionSheetDialog",
+          id = "actionSheetDialog",
           title = "Click me to launch a Toast!",
           type = "confirm",
-          text = "You clicked on the second button",
-          session = session
+          text = "You clicked on the second button"
         )
       }
     })
@@ -351,51 +336,48 @@ shinyApp(
           text = "You clicked on the first button",
           icon = f7Icon("bolt_fill"),
           title = "Notification",
-          titleRightText = "now",
-          session = session
+          titleRightText = "now"
         )
       } else if (input$swipeAction_button == 2) {
         f7Dialog(
-          inputId = "actionSheetDialog",
+          id = "actionSheetDialog",
           title = "Click me to launch a Toast!",
           type = "confirm",
-          text = "You clicked on the second button",
-          session = session
+          text = "You clicked on the second button"
         )
       }
     })
 
     observeEvent(input$actionSheetDialog, {
-      f7Toast(session, text = paste("Alert input is:", input$actionSheetDialog))
+      f7Toast(text = paste("Alert input is:", input$actionSheetDialog))
     })
 
     # update progress bar
     observeEvent(input$updatepg1, {
-      updateF7Progress(session, id = "pg1", value = input$updatepg1)
+      updateF7Progress(id = "pg1", value = input$updatepg1)
     })
 
     # update gauge
     observeEvent(input$updategauge1, {
-      updateF7Gauge(session, id = "mygauge1", value = input$updategauge1)
+      updateF7Gauge(id = "mygauge1", value = input$updategauge1)
     })
 
     # expand card 3
     observeEvent(input$goCard, {
-      updateF7Card(id = "card3", session = session)
+      updateF7Card(id = "card3")
     })
 
     # toggle accordion
     observeEvent(input$goAccordion, {
       updateF7Accordion(
-        inputId = "accordion1",
-        selected = 1,
-        session = session
+        id = "accordion1",
+        selected = 1
       )
     })
 
     # update panel
     observeEvent(input$goPanel, {
-      updateF7Panel(inputId = "panelLeft", session = session)
+      updateF7Panel(id = "panelLeft")
     })
 
     # swipeout
@@ -405,16 +387,14 @@ shinyApp(
         icon = f7Icon("bolt_fill"),
         title = "Notification",
         subtitle = "A subtitle",
-        titleRightText = "now",
-        session = session
+        titleRightText = "now"
       )
     })
 
     observeEvent(input$swipeAlert, {
       f7Dialog(
         title = "Dialog title",
-        text = "This is an alert dialog",
-        session = session
+        text = "This is an alert dialog"
       )
     })
 
@@ -447,13 +427,34 @@ shinyApp(
       hist(rnorm(100))
     })
 
+    # photo browser
+    observeEvent(input$togglePhoto, {
+      f7PhotoBrowser(
+        theme = "dark",
+        type = "standalone",
+        photos = c(
+          "https://cdn.framework7.io/placeholder/sports-1024x1024-1.jpg",
+          "https://cdn.framework7.io/placeholder/sports-1024x1024-2.jpg",
+          "https://cdn.framework7.io/placeholder/sports-1024x1024-3.jpg"
+        )
+      )
+    })
+
+    # Menus
+    observeEvent(input$toggleMenu, {
+      openF7MenuDropdown("menu1")
+    })
+
+    observeEvent(input$menuItem1, {
+      f7Notif(text = "Well done!")
+    })
+
     # pull to refresh
     # observeEvent(input$ptr, {
     #
     #   ptrStatus <- if (input$ptr) "on"
     #
     #   f7Dialog(
-    #     session = session,
     #     text = paste('ptr is', ptrStatus),
     #     type = "alert"
     #   )
