@@ -17,8 +17,13 @@ test_that("dependencies", {
   ui <- shinyMobile:::create_app_ui(iframeApp, device, color = NULL, landscape)
   deps <- htmltools::findDependencies(ui)
 
+  # we need index since shiny might not have the same version
+  # locally and on CRAN machines ... (dependencies are not in the same order)
+  deps_names <- vapply(deps, `[[`, "name", FUN.VALUE = character(1))
+  idx <- which(deps_names == "marvel-devices-css")
+
   expect_length(deps, 2)
-  expect_equal(deps[[1]]$name, "framework7")
-  expect_equal(deps[[1]]$version, "5.5.0")
-  expect_equal(deps[[1]]$stylesheet, "devices/devices.min.css")
+  expect_equal(deps[[idx]]$name, "marvel-devices-css")
+  expect_equal(deps[[idx]]$version, "1.0.0")
+  expect_equal(deps[[idx]]$stylesheet, "devices.min.css")
 })
